package org.zeroturnaround.javarebel.integration.servlet;

import org.zeroturnaround.javarebel.integration.servlet.util.ServletUtil;

import java.io.IOException;
import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.zeroturnaround.javarebel.Logger;
import org.zeroturnaround.javarebel.LoggerFactory;

/**
 * Filter that redirects a client from the root path to a given location.
 * 
 * Usage:
 * <pre>
 * &lt;filter&gt;
 *   &lt;filter-name&gt;redirectFilter&lt;/filter-name&gt;
 *   &lt;filter-class&gt;org.zeroturnaround.javarebel.integration.servlet.WelcomeFilter&lt;/filter-class&gt;
 *   &lt;init-param&gt;
 *     &lt;param-name&gt;location&lt;/param-name&gt;
 *     &lt;param-value&gt;sample.jsp&lt;/param-value&gt;
 *   &lt;/init-param&gt;
 * &lt;/filter&gt;
 * 
 * &lt;filter-mapping&gt;
 *   &lt;filter-name&gt;redirectFilter&lt;/filter-name&gt;
 *   &lt;url-pattern&gt;/&lt;/url-pattern&gt;
 * &lt;/filter-mapping&gt;
 * </pre>
 * 
 * @author Rein Raudjärv
 */
public class WelcomeFilter implements Filter {

	private static final Logger log = LoggerFactory.getInstance();
	
	private static final String LOCATION_PARAM = "location";
	
	private String location;
	
	public void init(FilterConfig config) throws ServletException {
		log.log("WelcomeFilter initialized");
		
		location = config.getInitParameter(LOCATION_PARAM);
		if (location == null)
			throw new ServletException("Init parameter '" + LOCATION_PARAM + "' is missing.");
	}

	public void doFilter(ServletRequest req, ServletResponse resp, FilterChain chain) throws IOException, ServletException {
		String path = ServletUtil.getUriFromRequest((HttpServletRequest) req);
		if ("/".equals(path)) {
			log.log("WelcomeFilter redirects");
			
			((HttpServletResponse) resp).sendRedirect(location);
		}
		else
			chain.doFilter(req, resp);
	}

	public void destroy() {
	}

}