package org.zeroturnaround.javarebel.integration.servlet.util;

import javax.servlet.http.HttpServletRequest;

public class ServletUtil {

	/**
	 * Returns the requested resource URI.
	 * <p>
	 * The requested resource may also be the target of a <code>RequestDispatcher.include()</code>
	 * 
	 * @param req request.
	 * @return requested resource URI.
	 */
	public static String getUriFromRequest(HttpServletRequest req) {
		/*
		 * Check to see if the requested JSP has been the target of a
		 * RequestDispatcher.include()
		 */
		String uri = (String) req.getAttribute("javax.servlet.include.servlet_path");
		if (uri != null) {
			/*
			 * Requested JSP has been target of RequestDispatcher.include(). Its
			 * path is assembled from the relevant javax.servlet.include.* request
			 * attributes
			 */
			String pathInfo = (String) req.getAttribute("javax.servlet.include.path_info");
			if (pathInfo != null) {
				uri += pathInfo;
			}
		}
		else {
			/*
			 * Requested JSP has not been the target of a
			 * RequestDispatcher.include(). Reconstruct its path from the request's
			 * getServletPath() and getPathInfo()
			 */
			uri = req.getServletPath();
			String pathInfo = req.getPathInfo();
			if (pathInfo != null) {
				uri += pathInfo;
			}
		}
		return uri;
	}
}
